@@ -4,13 +4,15 @@ print.CopyDetect<- function(x, ...){
 	cat("CopyDetect -- An R Package to Compute Statistical Indices for Detecting","\n")
 	cat("             ","Answer Copying on Multiple-Choice Tests","\n")
 	cat("","\n")
-	cat("Version 1.0  2012","\n")
+	cat("Version 1.1  2014","\n")
 	cat("","\n")
 	cat("Cengiz Zopluoglu","\n")
 	cat("","\n")
-	cat("University of Minnesota - Department of Educational Psychology","\n")
+	cat("Assistant Professor","\n")
+	cat("University of Miami - Department of Educational and Psychological Studies","\n")
+	cat("Research, Measurement, and Evaluation Program","\n")
 	cat("","\n")
-	cat("zoplu001@umn.edu","\n")
+	cat("c.zopluoglu@miami.edu","\n")
 	cat("*************************************************************************","\n")
 	cat("","\n")
 	cat("Processing Date: ",date(),"\n")
